# ListApplicationsResponse

Response object for application list

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**applications** | [**[Application]**](Application.md) | List of applications | [optional] 
**page_info** | [**PageInfo**](PageInfo.md) |  | [optional] 
**limit** | **int** | Limit on the number of rows in the response | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


